@@ -14,8 +14,10 @@
 
 #if SIZEOF_UNSIGNED_LONG_INT == 4
  typedef unsigned long word32;
+ typedef signed long sword32;
 #elif SIZEOF_UNSIGNED_INT == 4
  typedef unsigned int word32;
+ typedef signed int sword32;
 #else
 # error "Cannot find a 32 bit integer in your system, sorry."
 #endif
@@ -47,3 +49,5 @@
 
 #define ENCRYPT 0
 #define DECRYPT 1
+
+#define MAX_KEY_LEN 513 /* for gen_key */
